# quicksight-bulk-update-datasets

Makes bulk updates to Quicksight datasets.

> [!NOTE]
> The only bulk update currently supported is a rename of table schema


## Installation

```shell
pip install quicksight-bulk-update-datasets
```


## Usage

See the source in [quicksight_bulk_update_datasets.py](https://github.com/uktrade/quicksight-bulk-update-datasets/blob/main/quicksight_bulk_update_datasets.py), or after installation run

```shell
quicksight-bulk-update-datasets --help
```

to see some brief guidance.
